@@ -48,35 +48,38 @@ class Album(TimeStampedModel):
         return self.artists.first()
 
     def fix_metadata(self):
-        musicbrainzngs.set_useragent('vrobbler', '0.3.0')
-        mb_data = musicbrainzngs.get_release_by_id(
-            self.musicbrainz_id, includes=['artists']
-        )
-        if not self.musicbrainz_albumartist_id:
-            self.musicbrainz_albumartist_id = mb_data['release'][
-                'artist-credit'
-            ][0]['artist']['id']
-        if not self.year:
-            self.year = mb_data['release']['date'][0:4]
-        self.save(update_fields=['musicbrainz_albumartist_id', 'year'])
+        if not self.musicbrainz_albumartist_id or not self.year:
+            musicbrainzngs.set_useragent('vrobbler', '0.3.0')
+            mb_data = musicbrainzngs.get_release_by_id(
+                self.musicbrainz_id, includes=['artists']
+            )
+            if not self.musicbrainz_albumartist_id:
+                self.musicbrainz_albumartist_id = mb_data['release'][
+                    'artist-credit'
+                ][0]['artist']['id']
+            if not self.year:
+                self.year = mb_data['release']['date'][0:4]
+            self.save(update_fields=['musicbrainz_albumartist_id', 'year'])
 
-        new_artist = Artist.objects.filter(
-            musicbrainz_id=self.musicbrainz_albumartist_id
-        ).first()
-        if self.musicbrainz_albumartist_id and new_artist:
-            self.artists.add(new_artist)
-        if not new_artist:
-            for t in self.track_set.all():
-                self.artists.add(t.artist)
+            new_artist = Artist.objects.filter(
+                musicbrainz_id=self.musicbrainz_albumartist_id
+            ).first()
+            if self.musicbrainz_albumartist_id and new_artist:
+                self.artists.add(new_artist)
+            if not new_artist:
+                for t in self.track_set.all():
+                    self.artists.add(t.artist)
 
     def fetch_artwork(self):
-        try:
-            img_data = musicbrainzngs.get_image_front(self.musicbrainz_id)
-            name = f"{self.name}_{self.uuid}.jpg"
-            self.cover_image = ContentFile(img_data, name=name)
+        if not self.cover_image:
+            try:
+                img_data = musicbrainzngs.get_image_front(self.musicbrainz_id)
+                name = f"{self.name}_{self.uuid}.jpg"
+                self.cover_image = ContentFile(img_data, name=name)
+            except musicbrainzngs.ResponseError:
+                logger.warning(f'No cover art found for {self.name}')
+                self.cover_image = 'default-image-replace-me'
             self.save()
-        except musicbrainzngs.ResponseError:
-            logger.warning(f'No cover art found for {self.name}')
 
     @property
     def mb_link(self):
@@ -132,8 +135,10 @@ class Track(ScrobblableMixin):
             logger.debug(f"Created new album {album}")
         else:
             logger.debug(f"Found album {album}")
+
         album.fix_metadata()
-        album.fetch_artwork()
+        if not album.cover_image:
+            album.fetch_artwork()
 
         track_dict['album_id'] = getattr(album, "id", None)
         track_dict['artist_id'] = artist.id
